@@ -4,6 +4,187 @@
 # Licence GPL v3
 
 
+
+### from terra
+setAs("SpatRaster", "Raster", 
+	function(from) {
+		if (any(terra::window(from))) {
+			stop("you must remove the 'window' from the SpatRaster before coercion to a Raster*")
+		}
+		b <- sources(from, bands=TRUE)
+		nl <- nlyr(from)
+		e <- as.vector(ext(from))
+		prj <- crs(from) #, proj=TRUE)
+		if (nl == 1) {
+			if (b$source == "") {
+				r <- raster::raster(ncols=ncol(from), nrows=nrow(from), crs=prj,
+			          xmn=e[1], xmx=e[2], ymn=e[3], ymx=e[4])
+				if (hasValues(from)) {
+					raster::values(r) <- values(from)
+				}
+			} else {
+				r <- raster::raster(b$source, band=b$bands)
+			}
+		} else {
+			usid <- unique(b$sid)
+			if ((length(usid) == 1) & (b$source[1] != "")) {
+				if ((nl == nrow(b)) && (b$bands[1] == 1) && (all(diff(b$bands) == 1))) {
+					r <- raster::brick(b$source[1])
+					if (nlayers(r) != nl) {
+						r <- r[[b$bands]]
+					}
+				} else {
+					r <- raster::stack(b$source[1], bands=b$bands)
+				}
+			} else if (all(b$source=="")) {
+				r <- raster::brick(ncol=ncol(from), nrow=nrow(from), crs=prj,
+			          xmn=e[1], xmx=e[2], ymn=e[3], ymx=e[4], nl=nlyr(from))
+				if (hasValues(from)) {
+					raster::values(r) <- values(from)
+				}
+			} else {
+				x <- raster::raster(ncol=ncol(from), nrow=nrow(from), crs=prj,
+			          xmn=e[1], xmx=e[2], ymn=e[3], ymx=e[4])
+				r <- list()
+				b$layer <- 1:nrow(b)
+				for (i in usid) {
+					bi <- b[b$sid == usid[i], ,drop=FALSE]
+					if (bi$source[1] == "") {
+						r[[i]] <- raster::setValues(x, values(from[[ bi$layer ]]))
+					} else {
+						bands <- bi$bands
+						if (length(bands) > 1) {
+							r[[i]] <- raster::stack(b$source[i], bands=bands)
+						} else {
+							r[[i]] <- raster::raster(b$source[i], band=bands)						
+						}
+					}
+				}
+				r <- raster::stack(r)
+			}
+		}
+
+		if (hasValues(from)) {
+			so <- scoff(from)
+			gain(r) <- so[,1]
+			offs(r) <- so[,2]
+		}
+		
+		# things that may be different than the file source
+		try(levels(r) <- cats(from), silent=TRUE)
+		try(names(r) <- names(from))
+		#crs(r) <- crs(from)
+		extent(r) <- as.vector(ext(from))
+		projection(r) <- crs(from, proj=TRUE)
+		r
+	}
+)
+
+
+
+## to terra
+
+.fromRasterLayerBrick <- function(from) {
+	 
+	if (fromDisk(from)) {
+		f <- filename(from)
+		if (from@file@driver == "netcdf") {
+			v <- attr(from@data, "zvar")
+			r <- rast(f, v)	
+		} else {
+			r <- try(rast(f), silent=TRUE)
+			if (inherits(r, "try-error")) {
+				r <- rast(from + 0)
+				levs <- levels(from)[[1]]
+				if (!is.null(levs)) {
+					levels(r) <- levs
+				}
+			}
+			if (nbands(from) != nlayers(from)) {
+				r <- r[[bandnr(from)]]
+			}
+		}
+		if (from@file@NAchanged) {
+			NAflag(r) <- from@file@nodatavalue
+		}
+		scoff(r) <- cbind(gain(from), offs(from))
+		
+	} else {
+		r <- rast(	nrows=nrow(from), 
+					ncols=ncol(from),
+					nlyrs=nlayers(from),
+					extent=extent(from))
+		if (hasValues(from)) {
+			values(r) <- values(from)
+		}
+		levs <- levels(from)[[1]]
+		if (!is.null(levs)) {
+			if (ncol(levs) == 1) {
+				levs <- cbind(value=1:nrow(levs), levs)
+			}
+			levels(r) <- levs				
+		}
+	}
+	if (.hasSlot(from, "srs")) {
+		prj <- from@srs
+	} else {
+		prj <- .srs_from_sp(from@crs)	
+	}
+	crs(r, warn=FALSE) <- prj	
+	
+	#z <- from@z
+	#if (length(z) == 1) {
+	#	z <- z[[1]]
+	#	try(time(r) <- z, silent=TRUE)
+	#}
+	r
+}
+
+.fromRasterStack <- function(from) {
+	nl <- nlayers(from)
+	ff <- sapply(1:nl, function(i) { filename(from[[i]]) })
+	uff <- unique(ff)
+	if (length(uff) == 1) {
+		if (uff == "") {
+			return(.fromRasterLayerBrick(from))
+		} else {
+			n <- nbands(from[[1]])
+			bnr <- sapply(1:nl, function(i) { bandnr(from[[i]]) })
+			if ((n == nl) && all(bnr == 1:n)) {
+				return( rast(uff) )
+			}
+		}
+	} 
+	s <- lapply(1:nlayers(from), function(i) {
+		x <- from[[i]]
+		.fromRasterLayerBrick(x)
+	})
+	out <- do.call(c, s)
+	g <- gc()
+	out
+}
+
+
+setAs("Raster", "SpatRaster", 
+	function(from) {
+		if (inherits(from, "RasterLayer") || inherits(from, "RasterBrick")) { 
+			x <- .fromRasterLayerBrick(from)
+		} else {
+			x <- .fromRasterStack(from)
+		}
+		names(x) <- names(from)
+		ext(x) <- as.vector(extent(from))
+		if (.hasSlot(from, "srs")) {
+			prj <- from@srs
+		} else {
+			prj <- .srs_from_sp(from@crs)	
+		}
+		crs(x, warn=FALSE) <- prj			
+		x
+	}
+)
+
+
 # To sp pixel/grid objects	
 
 
@@ -11,7 +192,7 @@ setAs("Raster", "GridTopology",
 	function(from) {
 		rs <- res(from)
 		orig <- bbox(from)[,1] + 0.5 * rs
-		GridTopology(orig, rs, dim(from)[2:1] )
+		sp::GridTopology(orig, rs, dim(from)[2:1] )
 	}
 )
 
@@ -30,9 +211,9 @@ setAs("Raster", "SpatialPixels",
 		sp <- rasterToPoints(from, fun=NULL, spatial=FALSE)
 		
 		r <- raster(from)
-		sp <- SpatialPoints(sp[,1:2,drop=FALSE], proj4string= .getCRS(r))
+		sp <- sp::SpatialPoints(sp[,1:2,drop=FALSE],  proj4string= .getCRS(r))
 		grd <- as(r, "GridTopology")
-		SpatialPixels(points=sp, grid=grd)
+		sp::SpatialPixels(points=sp, grid=grd)
 	}
 )
 
@@ -44,7 +225,7 @@ setAs("Raster", "SpatialPixelsDataFrame",
 		v <- rasterToPoints(from, fun=NULL, spatial=FALSE)
 
 		r <- raster(from)
-		sp <- SpatialPoints(v[,1:2,drop=FALSE], proj4string= .getCRS(r))
+		sp <- sp::SpatialPoints(v[,1:2,drop=FALSE],  proj4string= .getCRS(r))
 
 		grd <- as(r, "GridTopology")
 		
@@ -58,10 +239,10 @@ setAs("Raster", "SpatialPixelsDataFrame",
 					}
 				}
 			}
-			SpatialPixelsDataFrame(points=sp, data=v, grid=grd)
+			sp::SpatialPixelsDataFrame(points=sp, data=v, grid=grd)
 		} else {
 			warning("object has no values, returning a 'SpatialPixels' object")
-			SpatialPixels(points=sp, grid=grd)
+			sp::SpatialPixels(points=sp, grid=grd)
 		}
 	}
 )
@@ -74,7 +255,7 @@ setAs("Raster", "SpatialGrid",
 		}	
 		r <- raster(from)
 		grd <- as(r, "GridTopology")
-		SpatialGrid(grd, proj4string=.getCRS(r))
+		sp::SpatialGrid(grd,  proj4string=.getCRS(r))
 	}
 )
 
@@ -88,10 +269,10 @@ setAs("Raster", "SpatialGridDataFrame",
 		grd <- as(r, "GridTopology")
 
 		if (hasValues(from)) {
-			sp <- SpatialGridDataFrame(grd, proj4string=.getCRS(r), data=as.data.frame(from))
+			sp <- sp::SpatialGridDataFrame(grd,  proj4string=.getCRS(r), data=as.data.frame(from))
 		} else { 
 			warning("object has no values, returning a 'SpatialGrid' object")
-			sp  <- SpatialGrid(grd, proj4string=.getCRS(r))
+			sp  <- sp::SpatialGrid(grd,  proj4string=.getCRS(r))
 		}
 		sp
 	}
@@ -115,7 +296,7 @@ setAs("Raster", "SpatialPolygonsDataFrame",
 
 setAs("Raster", "SpatialPoints", 
 	function(from) { 
-		SpatialPoints(rasterToPoints(from, spatial=FALSE)[,1:2], proj4string=.getCRS(from))
+		sp::SpatialPoints(rasterToPoints(from, spatial=FALSE)[,1:2],  proj4string=.getCRS(from))
 	}
 )
 
@@ -129,14 +310,14 @@ setAs("Raster", "SpatialPointsDataFrame",
 setAs("Extent", "SpatialPolygons", 
 	function(from){ 
 		p <- rbind(c(from@xmin, from@ymin), c(from@xmin, from@ymax), c(from@xmax, from@ymax), c(from@xmax, from@ymin), c(from@xmin, from@ymin) )
-		SpatialPolygons(list(Polygons(list(Polygon(p)), "1"))) 
+		sp::SpatialPolygons(list(sp::Polygons(list(sp::Polygon(p)), "1"))) 
 	}
 )
 
 setAs("Extent", "SpatialLines", 
 	function(from){ 
 		p <- rbind(c(from@xmin, from@ymin), c(from@xmin, from@ymax), c(from@xmax, from@ymax), c(from@xmax, from@ymin), c(from@xmin, from@ymin) )
-		SpatialLines(list(Lines(list(Line(p)), "1"))) 
+		sp::SpatialLines(list(sp::Lines(list(sp::Line(p)), "1"))) 
 	}
 )
 
@@ -144,7 +325,7 @@ setAs("Extent", "SpatialLines",
 setAs("Extent", "SpatialPoints", 
 	function(from){ 
 		p <- cbind( x=c( from@xmin, from@xmin, from@xmax, from@xmax), y=c(from@ymin, from@ymax, from@ymin, from@ymax) )
-		SpatialPoints(p)
+		sp::SpatialPoints(p)
 	}
 )
 
@@ -453,3 +634,5 @@ setAs("grf", "RasterLayer",
 	# }	
 	# b
 # }
+
+
