@@ -46,11 +46,11 @@
 	} else {
 		cat("map info = {projection, 1, 1,", xmin(r),", ", ymax(r),", ", xres(r),", ", yres(r), "}\n", file = thefile)
 	}
-	if (.requireRgdal(FALSE)) {
-		cat("coordinate system string = {", wkt(r), "}\n", file = thefile, sep="")
-	} else {
+#	if (.requireRgdal(FALSE)) {
+#		cat("coordinate system string = {", wkt(r), "}\n", file = thefile, sep="")
+#	} else {
 		cat("projection info =", proj4string(r), "\n", file = thefile) 
-	}
+#	}
 	cat("z plot range = {", minValue(r),", ", maxValue(r), "}\n", file = thefile) 
 	
 	cat("band names = {", paste(names(r),collapse=","), "}", "\n", file = thefile)
